# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-25 10:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0023_auto_20170823_1200'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='poshardware',
            options={},
        ),
        migrations.AlterField(
            model_name='poshardware',
            name='name',
            field=models.CharField(max_length=250, verbose_name='Name'),
        ),
        migrations.AlterUniqueTogether(
            name='poshardware',
            unique_together=set([('pos', 'kind', 'name')]),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-21 16:08
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0028_auto_20170921_1703'),
        ('codenerix_pos', '0027_auto_20170921_1206'),
    ]

    operations = [
    ]
